@@ -3,11 +3,11 @@
 
 echo "<repo>/<component>:<tag> : $1"
 
-git config --global url."https://$GITHUB_TOKEN@github.com/open-cluster-management".insteadOf  "https://github.com/open-cluster-management"
+git config --global url."https://$GITHUB_TOKEN@github.com/stolostron".insteadOf  "https://github.com/stolostron"
 
 WORKDIR=`pwd`
 cd ${WORKDIR}/..
-git clone --depth 1 -b release-2.2 https://github.com/open-cluster-management/observability-kind-cluster.git
+git clone --depth 1 -b release-2.2 https://github.com/stolostron/observability-kind-cluster.git
 cd observability-kind-cluster
 ./setup.sh $1
 if [ $? -ne 0 ]; then
@@ -16,7 +16,7 @@ if [ $? -ne 0 ]; then
 fi
 
 cd ${WORKDIR}/..
-git clone --depth 1 -b release-2.2 https://github.com/open-cluster-management/observability-e2e-test.git
+git clone --depth 1 -b release-2.2 https://github.com/stolostron/observability-e2e-test.git
 cd observability-e2e-test
 
 # run test cases
