@@ -11,9 +11,9 @@ import (
 	"k8s.io/client-go/kubernetes/scheme"
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 
-	appsv1 "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1"
-	mcov1beta1 "github.com/open-cluster-management/multicluster-monitoring-operator/pkg/apis/observability/v1beta1"
-	mcoconfig "github.com/open-cluster-management/multicluster-monitoring-operator/pkg/config"
+	appsv1 "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1"
+	mcov1beta1 "github.com/stolostron/multicluster-monitoring-operator/pkg/apis/observability/v1beta1"
+	mcoconfig "github.com/stolostron/multicluster-monitoring-operator/pkg/config"
 )
 
 func TestCreatePlacementRule(t *testing.T) {
