@@ -5,7 +5,7 @@ package util
 import (
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 
-	mcov1beta1 "github.com/open-cluster-management/multicluster-monitoring-operator/pkg/apis/observability/v1beta1"
+	mcov1beta1 "github.com/stolostron/multicluster-monitoring-operator/pkg/apis/observability/v1beta1"
 )
 
 var log = logf.Log.WithName("util")
